@@ -45,6 +45,25 @@ struct Foo
     virtual ~Foo() = default;
 };
 
+#ifdef _LIBCPP_VERSION
+struct Result {};
+static Result theFunction() { return Result(); }
+static int resultDeletorCount;
+static void resultDeletor(Result (*pf)()) {
+  assert(pf == theFunction);
+  ++resultDeletorCount;
+}
+
+void test_pointer_to_function() {
+    { // https://bugs.llvm.org/show_bug.cgi?id=27566
+      std::shared_ptr<Result()> x(&theFunction, &resultDeletor);
+      std::shared_ptr<Result()> y(theFunction, resultDeletor);
+    }
+    assert(resultDeletorCount == 2);
+}
+#else // _LIBCPP_VERSION
+void test_pointer_to_function() {}
+#endif // _LIBCPP_VERSION
 
 int main()
 {
@@ -59,13 +78,15 @@ int main()
     assert(p->get_char() == 'e');
     }
 
-    { // https://llvm.org/bugs/show_bug.cgi?id=24137
+    { // https://bugs.llvm.org/show_bug.cgi?id=24137
     std::shared_ptr<Foo> p1       = std::make_shared<Foo>();
     assert(p1.get());
     std::shared_ptr<const Foo> p2 = std::make_shared<const Foo>();
     assert(p2.get());
     }
 
+    test_pointer_to_function();
+
 #if TEST_STD_VER >= 11
     nc = globalMemCounter.outstanding_new;
     {
